var searchData=
[
  ['s_5fptype_0',['s_pType',['../a01978.html#aa5b41a1b31828cfa322891edaa08b13c',1,'com::sun::star::uno::Array']]],
  ['seconds_1',['Seconds',['../a00886.html#a97f504b07d37dfb242c1716a08784802',1,'TimeValue::Seconds'],['../a00890.html#ad197c5802bf50cce01faf8786b7504c1',1,'_oslDateTime::Seconds']]],
  ['signal_2',['Signal',['../a00850.html#a90c8d16605cd687001dd637acb411eef',1,'oslSignalInfo']]],
  ['size_3',['Size',['../a00838.html#a0596b91fd07cb65933ff9c3c5e73f120',1,'oslProcessInfo']]],
  ['structsize_4',['StructSize',['../a00734.html#aed0b013ab18b23707b7b2788ef4fdd5e',1,'_rtl_TextEncodingInfo']]],
  ['systemtime_5',['SystemTime',['../a00838.html#a1a6d03b9ad4cdcedf887134d833fc71d',1,'oslProcessInfo']]]
];
